@@ -5,6 +5,8 @@
 #	Copyright (C) 1999, 2000, Andrew Arensburger.
 #	You may distribute this file under the terms of the Artistic
 #	License, as specified in the README file.
+#
+# $Id: Palm.pm,v 1.1 2005/03/09 03:51:22 christophe Exp $
 
 use strict;
 use warnings;
@@ -12,7 +14,7 @@ package Palm;
 use vars qw( $VERSION );
 
 # One liner, to allow MakeMaker to work.
-$VERSION = '1.011_01';
+$VERSION = do { my @r = (q$Revision: 1.1 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 
 =head1 NAME
 
@@ -74,17 +76,9 @@ sub mkpdbname {
 	return $name;
 }
 
-=head1 SOURCE CONTROL
-
-The source is in Github:
-
-	http://github.com/briandfoy/p5-Palm/tree/master
-	
 =head1 AUTHOR
 
-Alessandro Zummo, C<< <a.zummo@towertech.it> >>
-
-Currently maintained by brian d foy, C<< <bdfoy@cpan.org> >>
+Andrew Arensburger E<lt>arensb@ooblick.comE<gt>
 
 =head1 SEE ALSO
 
